@@ -51,6 +51,7 @@ from .errors import (
     ConfigError,
     IllegalArgumentError,
     NDJSONError,
+    NotSupportedError,
     ResourceNotFound,
     ServerNotAvailable,
 )
@@ -85,7 +86,7 @@ from .tracing import gen_trace_id
 from .users import Action, Permission, Share, Users
 from .utils import _ContextManager, find_project_root
 
-__version__ = "21.10.0"
+__version__ = "21.11.0"
 
 
 __all__ = (
@@ -138,6 +139,7 @@ __all__ = (
     "Jobs",
     "LocalImage",
     "NDJSONError",
+    "NotSupportedError",
     "PASS_CONFIG_ENV_NAME",
     "Parser",
     "Permission",
