@@ -2,11 +2,13 @@ from datetime import datetime, timezone
 from decimal import Decimal
 from typing import Callable
 
+import pytest
 from aiohttp import web
 from aiohttp.web import HTTPCreated, HTTPNoContent
 from aiohttp.web_exceptions import HTTPOk
+from yarl import URL
 
-from neuro_sdk import Client
+from neuro_sdk import Client, NotSupportedError
 from neuro_sdk.admin import (
     _Balance,
     _CloudProvider,
@@ -536,6 +538,20 @@ async def test_get_cluster_user(
         assert requested_users == ["test"]
 
 
+async def test_not_supported_admin_api(
+    aiohttp_server: _TestServerFactory, make_client: _MakeClient
+) -> None:
+    app = web.Application()
+
+    srv = await aiohttp_server(app)
+
+    async with make_client(srv.make_url("/api/v1"), admin_url=URL()) as client:
+        with pytest.raises(
+            NotSupportedError, match="admin API is not supported by server"
+        ):
+            await client._admin.get_cluster_user("default", "test")
+
+
 async def test_add_cluster_user(
     aiohttp_server: _TestServerFactory, make_client: _MakeClient
 ) -> None:
